================
Pics
================

Game of life
=================

Did you know?

Pulsar is the fourth most common oscillator in the game of life.

.. image:: http://www.conwaylife.com/w/images/e/ef/Pulsar.gif
   :width: 100


Python Powered
=================

Pulsar loves python as much as the minion in the image!

.. image:: https://lh5.googleusercontent.com/-xVSvSecp6kE/Uk3XDSCCHVI/AAAAAAAABIs/r1rnKMHbT_w/w1560-h878-no
   :width: 500


Logos
=======
Pulsar needs a logo, can you design one for us?

Logo 1
~~~~~~~~~~
By Luca Sbardella

.. image:: _static/pulsar.png
   :width: 200 px


Logo 2
~~~~~~~~~~
By Luca Sbardella

Inspired from one of the pulsar oscillator images

.. image:: _static/pulsar3.png
   :width: 200 px


Logo 3
~~~~~~~~~~
By Luca Sbardella

.. image:: _static/pulsar-logo.svg
   :width: 200 px

.. image:: _static/pulsar-banner.svg
  :width: 600 px

Logo 4
~~~~~~~~~~
By Ralf Hölzemer

A worm's eye view with
a spiral to symbolize the rotational energy of a Pulsar.
Creative_ commons license.

.. image:: _static/pulsar_logos/pulsar_colored_logo_only.svg
  :width: 200 px

.. image:: _static/pulsar_logos/pulsar_monochome_logo_only.svg
   :width: 200 px

.. image:: _static/pulsar_logos/pulsar_colored_id_horizontal.svg
  :width: 600 px

.. _Creative: http://creativecommons.org/licenses/by-nc/3.0/
